@@ -57,10 +57,10 @@ class Person:
         log.debug(">" + " ".join(cmd))
         result = subprocess.run(cmd, capture_output=True, text=True)
         try:
-            self.current_balance = float(result.stdout.strip())
+            self.current_balance = str(float(result.stdout.strip()))
             log.info(f"{self.phone_number} - {self.current_balance}")
         except Exception as e:
-            self.current_balance = None
+            self.current_balance = ''
             log.debug(e)
             log.error(
                 f"Failed to get balance for: {self.phone_number} ({self.user_address})")
@@ -101,13 +101,13 @@ class Person:
             try:
                 result = subprocess.run(cmd, capture_output=True,
                                         text=True)
-                log.info("Stdout: ", result.stdout)
-                log.info("Error: ", result.stderr)
+                log.info("Stdout: " + str(result.stdout))
+                log.info("Error: " + str(result.stderr))
             except Exception as e:
                 log.error(e)
 
     def to_row(self) -> List[str]:
-        return [self.phone_number, self.user_address, self.contract_address, self.current_balance, self.send_amount, self.timestamp]
+        return [self.phone_number, self.user_address, self.contract_address, self.current_balance, str(self.send_amount), self.timestamp]
 
 
 def person_from_row(row: List[str]) -> Person:
